@@ -9,13 +9,17 @@ from typing import Optional
 from functional_predicates.base import Base
 from functional_predicates.misc import sentinel
 from functional_predicates.predicate import Predicate
+from functional_predicates.predicates.operator import Contains
 from functional_predicates.predicates.operator import Eq
 from functional_predicates.predicates.operator import GE
 from functional_predicates.predicates.operator import GT
+from functional_predicates.predicates.operator import Is_
+from functional_predicates.predicates.operator import IsNot
 from functional_predicates.predicates.operator import LE
 from functional_predicates.predicates.operator import LT
 from functional_predicates.predicates.operator import NE
 from functional_predicates.predicates.operator import Not_
+from functional_predicates.predicates.operator import Truth
 from functional_predicates.predicates.types import Callable
 from functional_predicates.predicates.types import IsInstance
 
@@ -53,6 +57,18 @@ class Checker(Base):
     def not_(self: Checker) -> Checker:
         return self._append(Not_)
 
+    def truth(self: Checker) -> Checker:
+        return self._append(Truth)
+
+    def is_(self: Checker, x: Any) -> Checker:
+        return self._append(Is_, x)
+
+    def is_not(self: Checker, x: Any) -> Checker:
+        return self._append(IsNot, x)
+
+    def contains(self: Checker, x: Any) -> Checker:
+        return self._append(Contains, x)
+
     # types
 
     def callable(self: Checker) -> Checker:  # noqa: A003
